@@ -550,8 +550,7 @@ class ExecutionServer(BaseServer):
             LOGGER.critical("No average speed to report yet.")
             
     def executeJobs(self, data=None):
-        deferreds = []
-        for i in range(0, 10):            
+        for i in range(0, 100):            
             if len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
                 job = self.job_queue.pop(0)
                 exposed_function = job["exposed_function"]
@@ -569,12 +568,9 @@ class ExecutionServer(BaseServer):
                 d.addCallback(self._jobCountCallback)
                 d.addErrback(self._jobCountErrback)
                 d.addCallback(self._setNextRequest, uuid, exposed_function["interval"], function_name)
-                deferreds.append(d)
             else:
-                break
-        if len(deferreds) > 0:
-            d = DeferredList(deferreds)
-            d.addCallback(self.executeJobs())
+                return
+        reactor.callLater(.1, self.executeJobs)
             
     def _callExposedFunction(
         self, 
